==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/43/43b53a0bef761d98745532adef9eee3f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_glass_55_fbf9ee_1x400.png */
class __TwigTemplate_e4a774acb281e298413976e6803a21b0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000A\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000\000bKGD\tX\000\000\000tIME\t
\"!\000\000\000IDATH!
AblA1{VY0ixxvDK_O9\000aՔ}^JaȌ0bvBA\$,Q\"_44=SqcyEIW
<kAi0<a\$Sy.\000\000\000%tEXtdate:create\0002016-09-14T13:34:08-04:00_Dn\000\000\000%tEXtdate:modify\0002016-09-14T13:34:08-04:00.\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_glass_55_fbf9ee_1x400.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_glass_55_fbf9ee_1x400.png", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_glass_55_fbf9ee_1x400.png");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/43/43b53a0bef761d98745532adef9eee3f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_glass_55_fbf9ee_1x400.png */
class __TwigTemplate_e4a774acb281e298413976e6803a21b0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000A\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000\000bKGD\tX\000\000\000tIME\t
\"!\000\000\000IDATH!
AblA1{VY0ixxvDK_O9\000aՔ}^JaȌ0bvBA\$,Q\"_44=SqcyEIW
<kAi0<a\$Sy.\000\000\000%tEXtdate:create\0002016-09-14T13:34:08-04:00_Dn\000\000\000%tEXtdate:modify\0002016-09-14T13:34:08-04:00.\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_glass_55_fbf9ee_1x400.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_glass_55_fbf9ee_1x400.png", "/var/www/html/production-demo/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_glass_55_fbf9ee_1x400.png");
    }
}
